"use client";
import Image from "next/image";

import { ContentLines } from "@/components/shared/content-lines";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useLocale, useTranslations } from "next-intl";


export function AboutProjectClient() {

	const { texts } = useBasicInfo();
	const locale = useLocale() as Locale;
	const t = useTranslations();

	return (
		<section className="overflow-hidden bg-custom-background-third">
			<div className="container relative mx-auto max-w-7xl px-4 py-24 lg:px-40">
				<div className="flex flex-col items-center justify-between gap-20 lg:flex-row">
					{/* Content */}
					<div className="w-full rounded-lg bg-custom-background-light px-6 py-8 shadow-[0_78px_34px_-45px_rgba(0,0,0,0.15)] lg:w-[60%]"
						style={{ zIndex: "999" }}>
						<div className="flex flex-col justify-between gap-6">
							<ContentLines
								title={t("Projects")}
								underlineColor="custom-primary-accent"
								textColor="text-primary-accent"
								padding="none"
							/>

							<h2 className="text-xl leading-tight text-custom-dark-veryDark lg:text-3xl">
								{texts?.projects_first_section_title?.[locale]}
							</h2>
							<p className="leading-relaxed text-custom-dark-light">
								{texts?.projects_first_section_description?.[locale]}
							</p>
						</div>
					</div>

					{/* Main image */}
					<div className="relative w-full lg:w-[40%]">
						<div className="absolute -left-4 -top-4 h-full w-full bg-custom-border rounded-lg" />
						<Image
							src={ImageBaseUrl + texts?.projects_first_section_img}
							alt={""}
							width={387}
							height={487}
							className="relative z-10 h-auto w-full rounded-lg object-cover drop-shadow-[2px_2px_2px_rgba(0,0,0,0.5)] filter"
						/>
					</div>

					{/* Wave Background */}
					<div className="pointer-events-none absolute inset-0 z-0 overflow-hidden">
						<div className="absolute bottom-0 right-0 h-1/3 w-1/2 lg:h-2/3 lg:w-full">
							<Image
								src={"/wave.png"}
								alt="Wave background"
								fill
								quality={100}
								className="object-cover object-right-bottom"
								style={{
									maskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
									WebkitMaskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
								}}
							/>
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}
